@@ -38,6 +38,8 @@ private:
     QList<QString> *savedFiles;
     QList<QString> *allLoadedFiles;
     QStringList articleLinkList;
+    QString strippedtitle;
+    QList<QString> *parsed;
 
 };
 
