@@ -241,8 +241,10 @@ void MainWindow::article_selected(QTableWidgetItem *item)
 {
     message->setLabelText("Loading " + item->text());
     QString stripped = item->text().toLower().remove(QRegExp("[^A-Za-z0-9]"));
-    message->show();
     bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+    if (!existsAlready)
+        message->show();
+
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -251,11 +253,14 @@ void MainWindow::openArticleFromLink(QListWidgetItem *item)
     if (player->isVisible())
         player->hide();
     message->setLabelText("Loading " + item->text());
-    message->show();
-
     QString stripped = item->text().toLower().remove(QRegExp("[^A-Za-z0-9]"));
-
     bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  stripped+".txt").exists();
+    if (!existsAlready)
+        message->show();
+
+
+
+
     qDebug()<<"openarticlefromlink"<<stripped<<existsAlready;
     network->retrieveArticle(item->text(), existsAlready);
 }
@@ -360,9 +365,8 @@ void MainWindow::newSearch(QString keyword)
 void MainWindow::openArticleInPlayer(QString title, QString article)
 {
 
-
         qDebug()<<"open"<<title;
-         message->setLabelText("Processing " + title);
+
          player->openArticle(title, article, openPlaylist);
          ui->playerButton->setDown(true);
          ui->mainWindowButton->setDown(false);
@@ -372,10 +376,12 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
          {
              qDebug()<<openPlaylist;
              openPlaylist = false;
-          //   player->setPlaylistFocus();
+             player->setPlaylistFocus();
+             message->hide();
          }
          else
          {
+             message->setLabelText("Processing " + title);
              if(!player->isVisible())
                 player->show();
          }
